Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/typedal/__about__.py | 1 | 0 | 0 | 100%
src/typedal/__init__.py | 5 | 0 | 2 | 100%
src/typedal/caching.py | 169 | 0 | 3 | 100%
src/typedal/cli.py | 92 | 6 | 164 | 93%
src/typedal/config.py | 132 | 0 | 11 | 100%
src/typedal/core.py | 903 | 0 | 144 | 100%
src/typedal/fields.py | 85 | 0 | 0 | 100%
src/typedal/for_py4web.py | 10 | 0 | 12 | 100%
src/typedal/for_web2py.py | 31 | 0 | 0 | 100%
src/typedal/helpers.py | 80 | 0 | 0 | 100%
src/typedal/serializers/as_json.py | 15 | 0 | 25 | 100%
src/typedal/types.py | 64 | 0 | 0 | 100%
src/typedal/web2py_py4web_shared.py | 18 | 0 | 0 | 100%
Total | 1605 | 6 | 361 | 99%

No items found using the specified filter.